@@ -1,8 +1,4 @@
 package App::ListOrgAnniversaries;
-BEGIN {
-  $App::ListOrgAnniversaries::VERSION = '0.05';
-}
-#ABSTRACT: List headlines in Org files
 
 use 5.010;
 use strict;
@@ -17,13 +13,15 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(list_org_anniversaries);
 
+our $VERSION = '0.06'; # VERSION
+
 our %SPEC;
 
 my $today;
 my $yest;
 
 sub _process_hl {
-    my ($file, $hl, $args, $res) = @_;
+    my ($file, $hl, $args, $res, $opts) = @_;
 
     return unless $hl->is_leaf;
 
@@ -66,7 +64,8 @@ sub _process_hl {
                         next;
                     }
                     push @annivs,
-                        [$k, DateTime->new(year=>$1, month=>$2, day=>$3)];
+                        [$k, DateTime->new(year=>$1, month=>$2, day=>$3,
+                                       time_zone=>$opts->{time_zone})];
                     return;
                 }
             }
@@ -170,11 +169,21 @@ _
             summary => 'Don\'t show dates that are overdue '.
                 'more than this number of days',
         }],
-    },
+        time_zone => [str => {
+            summary => 'Will be passed to parser\'s options',
+            description => <<'_',
+
+If not set, TZ environment variable will be picked as default.
+
+_
+        }],
+   },
 };
 sub list_org_anniversaries {
     my %args = @_;
 
+    my $tz = $args{time_zone} // $ENV{TZ};
+
     # XXX schema
     my $files = $args{files};
     return [400, "Please specify files"] if !$files || !@$files;
@@ -182,7 +191,7 @@ sub list_org_anniversaries {
     return [400, "Invalid field_pattern: $@"] unless eval { $f = qr/$f/i };
     $args{field_pattern} = $f;
 
-    $today = DateTime->today;
+    $today = DateTime->today(time_zone => $tz);
     $yest  = $today->clone->add(days => -1);
 
     my $orgp = Org::Parser->new;
@@ -190,12 +199,13 @@ sub list_org_anniversaries {
 
     for my $file (@$files) {
         $log->debug("Parsing $file ...");
-        my $doc = $orgp->parse_file($file);
+        my $opts = {time_zone => $tz};
+        my $doc = $orgp->parse_file($file, $opts);
         $doc->walk(
             sub {
                 my ($el) = @_;
                 return unless $el->isa('Org::Element::Headline');
-                _process_hl($file, $el, \%args, \@res)
+                _process_hl($file, $el, \%args, \@res, $opts)
             });
     } # for $file
 
@@ -203,6 +213,7 @@ sub list_org_anniversaries {
 }
 
 1;
+#ABSTRACT: List headlines in Org files
 
 
 =pod
@@ -213,7 +224,7 @@ App::ListOrgAnniversaries - List headlines in Org files
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -290,6 +301,12 @@ Filter headlines that don't have the specified tags.
 
 Don't show dates that are overdue more than this number of days.
 
+=item * B<time_zone> => I<str>
+
+Will be passed to parser's options.
+
+If not set, TZ environment variable will be picked as default.
+
 =back
 
 =head1 AUTHOR
